(corsika)=

# CORSIKA

Support modules for running CORSIKA.

## corsika_config

(corsika-config-1)=

```{eval-rst}
.. automodule:: corsika.corsika_config
   :members:
```

## primary_particle

```{eval-rst}
.. automodule:: corsika.primary_particle
   :members:
```

## corsika_histograms

(corsika-histograms-1)=

```{eval-rst}
.. automodule:: corsika.corsika_histograms
   :members:

```

## corsika_histograms_visualize

(corsika-histograms-visualize-1)=

```{eval-rst}
.. automodule:: corsika.corsika_histograms_visualize
   :members:
```
